@@ -97,9 +97,14 @@ class Server:
             self.sendTo(sSock, message)
 
     def sendTo(self, sock, data):
-        sock.send(bytes(json.dumps(data) + self.seq, "utf-8"))
-        if data["METHOD"] not in self.packagePrintBlacklist:
-            logger.log("§8[§eSERVER§8] §r[OUT] " + data["METHOD"])
+        try:
+            sock.send(bytes(json.dumps(data) + self.seq, "utf-8"))
+            if data["METHOD"] not in self.packagePrintBlacklist:
+                logger.log("§8[§eSERVER§8] §r[OUT] " + data["METHOD"])
+        except Exception as e:
+            logger.log("§8[§eSERVER§8] §8[§cWARNING§8] §cFailed to send data: " + str(e))
+            if e == BrokenPipeError:
+                sock.close()
 
     def sendToClient(self, clientID, data):
         for client in self.clients:
